@@ -327,6 +327,12 @@ add_changes <- function(.data, changes){
     .data %>% mutate_nodes(diffusion = "S")
 }
 
+#' @rdname manip_changes
+#' @export
+delete_changes <- function(.data){
+  igraph::delete_graph_attr(.data, "changes")
+}
+
 #' @rdname manip_changes
 #' @export
 mutate_changes <- function(.data, ...) UseMethod("mutate_changes")
