@@ -1,8 +1,7 @@
 #' Component partitioning algorithms
 #' 
 #' @description 
-#'   These functions create a vector of nodes' memberships in
-#'   components or degrees of coreness:
+#'   These functions create a vector of nodes' memberships in components:
 #'   
 #'   - `node_in_component()` assigns nodes' component membership
 #'   using edge direction where available.
@@ -22,11 +21,6 @@
 #'   Weakly connected components consist of subgraphs where there is a path
 #'   in either direction between member nodes.
 #'   
-#'   Coreness captures the maximal subgraphs in which each vertex has at least
-#'   degree _k_, where _k_ is also the order of the subgraph.
-#'   As described in `igraph::coreness`,
-#'   a node's coreness is _k_ if it belongs to the _k_-core
-#'   but not to the (_k_+1)-core.
 #' @inheritParams mark_is
 #' @name member_components
 #' @family memberships
@@ -34,13 +28,13 @@ NULL
 
 #' @rdname member_components 
 #' @importFrom igraph components
-# #' @examples 
-# #' ison_monks %>% to_uniplex("esteem") %>% 
-# #'   mutate_nodes(comp = node_in_component())
+#' @examples
+#' ison_monks %>% to_uniplex("esteem") %>%
+#'   mutate_nodes(comp = node_in_component())
 #' @export
 node_in_component <- function(.data){
-  if(missing(.data)) {expect_nodes(); .data <- .G()}
-  if(!is_graph(.data)) .data <- as_igraph(.data)
+  if(missing(.data)) {expect_nodes(); .data <- .G()} # nocov
+  if(!is_graph(.data)) .data <- as_igraph(.data) # nocov
   make_node_member(igraph::components(.data, mode = "strong")$membership,
               .data)
 }
@@ -49,8 +43,8 @@ node_in_component <- function(.data){
 #' @importFrom igraph components
 #' @export
 node_in_weak <- function(.data){
-  if(missing(.data)) {expect_nodes(); .data <- .G()}
-  if(!manynet::is_graph(.data)) .data <- manynet::as_igraph(.data)
+  if(missing(.data)) {expect_nodes(); .data <- .G()} # nocov
+  if(!manynet::is_graph(.data)) .data <- manynet::as_igraph(.data) # nocov
   make_node_member(igraph::components(.data, mode = "weak")$membership,
                  .data)
 }
@@ -59,8 +53,8 @@ node_in_weak <- function(.data){
 #' @importFrom igraph components
 #' @export
 node_in_strong <- function(.data){
-  if(missing(.data)) {expect_nodes(); .data <- .G()}
-  if(!manynet::is_graph(.data)) .data <- manynet::as_igraph(.data)
+  if(missing(.data)) {expect_nodes(); .data <- .G()} # nocov
+  if(!manynet::is_graph(.data)) .data <- manynet::as_igraph(.data) # nocov
   make_node_member(igraph::components(.data, mode = "strong")$membership,
                  .data)
 }
