@@ -23,3 +23,18 @@ test_that("network length works", {
   expect_equal(as.numeric(net_length(ison_southern_women)), 2.306, 
                tolerance = 0.001)
 })
+
+test_that("net_independence works", {
+  expect_s3_class(net_independence(ison_adolescents), "network_measure")
+  expect_values(net_independence(ison_adolescents), 4)
+})
+
+test_that("net_strength works", {
+  expect_s3_class(net_strength(ison_adolescents), "network_measure")
+  expect_values(net_strength(ison_adolescents), 0.5)
+})
+
+test_that("net_toughness works", {
+  expect_s3_class(net_toughness(ison_adolescents), "network_measure")
+  expect_values(net_toughness(ison_adolescents), 0.5)
+})
\ No newline at end of file
